<?PHP // $Id$ 
      // admin.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['blockinstances'] = 'Istanze';
$string['blockmultiple'] = 'Multiplo';
$string['cachetext'] = 'Durata cache del testo';
$string['change'] = 'cambia';
$string['filteruploadedfiles'] = 'Applica filtro sui file inviati';
$string['upgradelogs'] = 'Per la piena funzionalit, i vostri vecchi log devono essere aggiornati. <a href=\"$a\">Ulteriori informazioni</a>';
$string['upgradelogsinfo'] = 'Alcune modifiche hanno cambiato il modo in cui vengono salvati alcuni log. Per poter visualizzare tutti i vecchi log su una base di per-attivit,  necessario aggiornarli. In base al tuo sito questa operazione pu richiedere molto tempo (es alcune ore) e pu essere grosso lavoro per la base dati dei siti grandi. Una volta che l\'aggiornamento  iniziato devi lasciarlo terminare (mantenendo la finestra del browser aperta). Non preoccuparti - il tuo sito continuer a lavorare correttamente mentre i log vengono aggiornati.<br /><br />Vuoi aggiornare i log ora?';
$string['upgradesure'] = 'I file di Moodle sono cambiati, e si per aggiornare automaticamente la versione del server alla seguente versione:
<p><b>$a</b></p>
<p>Una volta effettuato questo non  possibile tornare indietro.</p>
<p>Siete sicuri di voler aggiornare questo server a quest versione?</p>';
$string['upgradinglogs'] = 'Aggiornamento log';

?>
